import { __decorate, __metadata, __extends } from 'tslib';
import { Component, ɵɵdefineInjectable, ɵɵinject, Injectable, NgModule, Injector, INJECTOR } from '@angular/core';
import { Validators, FormBuilder, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { ActivatedRoute, Router, RouterModule } from '@angular/router';
import { first, map, catchError, filter, take, switchMap, finalize, mergeMap, materialize, delay, dematerialize } from 'rxjs/operators';
import { AuthenticationService, NotificationType, NotificationService } from '@xdf/commons';
import { CommonModule } from '@angular/common';
import { TranslateModule, TranslateService } from '@ngx-translate/core';
import { throwError, of, BehaviorSubject } from 'rxjs';
import { HttpClient, HttpResponse } from '@angular/common/http';

var LoginComponent = /** @class */ (function () {
    function LoginComponent(formBuilder, route, router, authenticationService) {
        this.formBuilder = formBuilder;
        this.route = route;
        this.router = router;
        this.authenticationService = authenticationService;
        this.loading = false;
        this.submitted = false;
        this.error = '';
        // redirect to home if already logged
        if (this.authenticationService.currentUserValue) {
            this.router.navigate(['/home']);
        }
    }
    LoginComponent.prototype.ngOnInit = function () {
        this.loginForm = this.formBuilder.group({
            username: ['', Validators.required],
            password: ['', Validators.required]
        });
        // get return url from route parameters or default to '/'
        var attReturnUrl = 'returnUrl';
        this.returnUrl = this.route.snapshot.queryParams[attReturnUrl] || '/';
    };
    Object.defineProperty(LoginComponent.prototype, "f", {
        get: function () { return this.loginForm.controls; },
        enumerable: true,
        configurable: true
    });
    LoginComponent.prototype.onSubmit = function () {
        var _this = this;
        this.submitted = true;
        // stop here if form is invalid
        if (this.loginForm.invalid) {
            return;
        }
        this.loading = true;
        this.authenticationService.login(this.f.username.value, this.f.password.value)
            .pipe(first())
            .subscribe(function (data) {
            var returnUrl = JSON.parse(localStorage.getItem('returnUrl'));
            if (returnUrl) {
                _this.returnUrl = returnUrl;
                localStorage.removeItem('returnUrl');
            }
            _this.router.navigate([_this.returnUrl]);
        }, function (error) {
            _this.error = error;
            _this.loading = false;
        });
    };
    LoginComponent.ctorParameters = function () { return [
        { type: FormBuilder },
        { type: ActivatedRoute },
        { type: Router },
        { type: AuthenticationService }
    ]; };
    LoginComponent = __decorate([
        Component({
            selector: 'xdf-example-login',
            template: "<div class=\"col-md-6 offset-md-3 mt-5\">\n    <div class=\"alert alert-info\">\n        Username: test<br />\n        Password: test\n    </div>\n    <div class=\"card\">\n        <h4 class=\"card-header\">{{ 'login.title' | translate }}</h4>\n        <div class=\"card-body\">\n            <form [formGroup]=\"loginForm\" (ngSubmit)=\"onSubmit()\">\n                <div class=\"form-group\">\n                    <label for=\"username\">{{ 'label.username' | translate }}</label>\n                    <input type=\"text\" formControlName=\"username\" class=\"form-control\" [ngClass]=\"{ 'is-invalid': submitted && f.username.errors }\" />\n                    <div *ngIf=\"submitted && f.username.errors\" class=\"invalid-feedback\">\n                        <div *ngIf=\"f.username.errors.required\">Username is required</div>\n                    </div>\n                </div>\n                <div class=\"form-group\">\n                    <label for=\"password\">{{ 'label.password' | translate }}</label>\n                    <input type=\"password\" formControlName=\"password\" class=\"form-control\" [ngClass]=\"{ 'is-invalid': submitted && f.password.errors }\" />\n                    <div *ngIf=\"submitted && f.password.errors\" class=\"invalid-feedback\">\n                        <div *ngIf=\"f.password.errors.required\">Password is required</div>\n                    </div>\n                </div>\n                <button [disabled]=\"loading\" class=\"btn btn-primary\">\n                    <span *ngIf=\"loading\" class=\"spinner-border spinner-border-sm mr-1\"></span>\n                    Login\n                </button>\n                <div *ngIf=\"error\" class=\"alert alert-danger mt-3 mb-0\">{{ error }}</div>\n            </form>\n        </div>\n    </div>\n  </div>\n  ",
            styles: [""]
        }),
        __metadata("design:paramtypes", [FormBuilder,
            ActivatedRoute,
            Router,
            AuthenticationService])
    ], LoginComponent);
    return LoginComponent;
}());

var AuthorizationResource = /** @class */ (function () {
    function AuthorizationResource(program, control) {
        this.program = program;
        this.control = control;
    }
    return AuthorizationResource;
}());
var AuthorizationService = /** @class */ (function () {
    function AuthorizationService(http) {
        this.http = http;
    }
    AuthorizationService.prototype.authorize = function (programId) {
        return this.http.get("./service/security/controls/" + programId);
    };
    AuthorizationService.ctorParameters = function () { return [
        { type: HttpClient }
    ]; };
    AuthorizationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function AuthorizationService_Factory() { return new AuthorizationService(ɵɵinject(HttpClient)); }, token: AuthorizationService, providedIn: "root" });
    AuthorizationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [HttpClient])
    ], AuthorizationService);
    return AuthorizationService;
}());

var AuthorizationResolver = /** @class */ (function () {
    function AuthorizationResolver(authorizationService, notificationService) {
        this.authorizationService = authorizationService;
        this.notificationService = notificationService;
    }
    AuthorizationResolver.prototype.resolve = function (route) {
        var key = 'program';
        var program = route.data[key];
        if (!program) {
            this.notificationService.showMessage("Route requires 'program' parameter", 'Security Error!', NotificationType.error);
            return throwError("Not Found 'program' Parameter");
        }
        return this.authorizationService.authorize(program);
    };
    AuthorizationResolver.ctorParameters = function () { return [
        { type: AuthorizationService },
        { type: NotificationService }
    ]; };
    AuthorizationResolver = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [AuthorizationService,
            NotificationService])
    ], AuthorizationResolver);
    return AuthorizationResolver;
}());

var XdfSecurityModule = /** @class */ (function () {
    function XdfSecurityModule() {
    }
    XdfSecurityModule = __decorate([
        NgModule({
            declarations: [
                LoginComponent
            ],
            imports: [
                FormsModule,
                CommonModule,
                RouterModule,
                ReactiveFormsModule,
                TranslateModule
            ],
            exports: [
                LoginComponent
            ],
            providers: [
                AuthorizationResolver
            ]
        })
    ], XdfSecurityModule);
    return XdfSecurityModule;
}());

/**
 * @description
 * Permite validar que antes de usar el mantenimiento el usuario esté logueado en la aplicación.
 * La presente implementación supone que el login es parte de los routes configurados.
 */
var AuthGuard = /** @class */ (function () {
    function AuthGuard(router, authenticationService) {
        this.router = router;
        this.authenticationService = authenticationService;
    }
    AuthGuard.prototype.canLoad = function () {
        var currentUser = this.authenticationService.currentUserValue;
        var response = !(!currentUser);
        return of(response);
    };
    AuthGuard.prototype.canActivate = function (route, state) {
        var currentUser = this.authenticationService.currentUserValue;
        if (currentUser) {
            // logged in so return true
            return true;
        }
        // not logged in so redirect to login page with the return url
        if (state.url) {
            localStorage.setItem('returnUrl', JSON.stringify(state.url));
        }
        this.router.navigate(['login']);
        return false;
    };
    AuthGuard.ctorParameters = function () { return [
        { type: Router },
        { type: AuthenticationService }
    ]; };
    AuthGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function AuthGuard_Factory() { return new AuthGuard(ɵɵinject(Router), ɵɵinject(AuthenticationService)); }, token: AuthGuard, providedIn: "root" });
    AuthGuard = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [Router,
            AuthenticationService])
    ], AuthGuard);
    return AuthGuard;
}());

var OAuthGuard = /** @class */ (function () {
    function OAuthGuard(router, authenticationService) {
        this.router = router;
        this.authenticationService = authenticationService;
    }
    OAuthGuard.prototype.canLoad = function () {
        return this.authenticationService.login(null, null).pipe(map(function (user) {
            if (!user) {
                window.location.href = './';
                return false;
            }
            return true;
        }));
    };
    OAuthGuard.prototype.canActivate = function () {
        return this.authenticationService.login(null, null).pipe(map(function (user) {
            if (!user) {
                window.location.href = './';
                return false;
            }
            return true;
        }));
    };
    OAuthGuard.ctorParameters = function () { return [
        { type: Router },
        { type: AuthenticationService }
    ]; };
    OAuthGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function OAuthGuard_Factory() { return new OAuthGuard(ɵɵinject(Router), ɵɵinject(AuthenticationService)); }, token: OAuthGuard, providedIn: "root" });
    OAuthGuard = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [Router,
            AuthenticationService])
    ], OAuthGuard);
    return OAuthGuard;
}());

var ResourceAuthGuard = /** @class */ (function () {
    function ResourceAuthGuard(authorizationService, notificationService, translate) {
        this.authorizationService = authorizationService;
        this.notificationService = notificationService;
        this.translate = translate;
    }
    ResourceAuthGuard.prototype.canActivate = function (route, state) {
        var _this = this;
        var key = 'program';
        var program = route.data[key];
        if (!program) {
            this.notificationService.showMessage(this.translate.instant('security.message.error.parameter', { parameter: key }), this.translate.instant('security.message.error.title'), NotificationType.error);
            return throwError(this.translate.instant('security.message.error.parameter.not.found', { parameter: key }));
        }
        return this.authorizationService.authorize(program).pipe(map(function (data) {
            if (!data || data.length === 0) {
                _this.notificationService.showMessage(_this.translate.instant('message.error.resource.authorization'), _this.translate.instant('title.error'), NotificationType.error);
                return false;
            }
            var keyAuthorization = 'authorization';
            route.paramMap[keyAuthorization] = data;
            return true;
        }));
    };
    ResourceAuthGuard.ctorParameters = function () { return [
        { type: AuthorizationService },
        { type: NotificationService },
        { type: TranslateService }
    ]; };
    ResourceAuthGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function ResourceAuthGuard_Factory() { return new ResourceAuthGuard(ɵɵinject(AuthorizationService), ɵɵinject(NotificationService), ɵɵinject(TranslateService)); }, token: ResourceAuthGuard, providedIn: "root" });
    ResourceAuthGuard = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [AuthorizationService,
            NotificationService,
            TranslateService])
    ], ResourceAuthGuard);
    return ResourceAuthGuard;
}());

var ByteAuthenticationService = /** @class */ (function (_super) {
    __extends(ByteAuthenticationService, _super);
    function ByteAuthenticationService(http, injector) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.injector = injector;
        return _this;
    }
    ByteAuthenticationService.prototype.login = function (username, password) {
        var _this = this;
        return this.http.post("http://localhost:4200/users/authenticate", { username: username, password: password })
            .pipe(map(function (user) {
            // store user details and jwt token in local storage to keep user logged in between page refreshes
            localStorage.setItem('currentUser', JSON.stringify(user));
            if (_this.currentUserSubject) {
                _this.currentUserSubject.next(user);
            }
            else {
                _this.currentUserSubject = new BehaviorSubject(user);
            }
            _this.currentUser = _this.currentUserSubject.asObservable();
            return user;
        }));
    };
    ByteAuthenticationService.prototype.logout = function () {
        // remove user from local storage to log user out
        localStorage.removeItem('currentUser');
        localStorage.removeItem('menuInfo');
        this.currentUserSubject.next(null);
        var router = this.injector.get(Router);
        router.navigate(['/login']);
        return of();
    };
    ByteAuthenticationService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Injector }
    ]; };
    ByteAuthenticationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ByteAuthenticationService_Factory() { return new ByteAuthenticationService(ɵɵinject(HttpClient), ɵɵinject(INJECTOR)); }, token: ByteAuthenticationService, providedIn: "root" });
    ByteAuthenticationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [HttpClient, Injector])
    ], ByteAuthenticationService);
    return ByteAuthenticationService;
}(AuthenticationService));

var OAuthAuthenticationService = /** @class */ (function (_super) {
    __extends(OAuthAuthenticationService, _super);
    function OAuthAuthenticationService(http, injector) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.injector = injector;
        return _this;
    }
    OAuthAuthenticationService.prototype.login = function (username, password) {
        var _this = this;
        return this.http.get('./service/oauth/userinfo', { withCredentials: true }).pipe(map(function (response) {
            var key = 'userAuthentication';
            if (response && response[key]) {
                var user = response[key].details.principal;
                if (!user || user instanceof String) {
                    user = response[key].details;
                }
                if (!user) {
                    var router = _this.injector.get(Router);
                    console.error('No se ha identificado el usuario registrado');
                    router.navigate(['/notfound']);
                    return null;
                }
                localStorage.setItem('currentUser', JSON.stringify(user));
                if (_this.currentUserSubject) {
                    _this.currentUserSubject.next(user);
                }
                else {
                    _this.currentUserSubject = new BehaviorSubject(user);
                }
                _this.currentUser = _this.currentUserSubject.asObservable();
                return user;
            }
            else {
                return null;
            }
        }));
    };
    OAuthAuthenticationService.prototype.logout = function () {
        localStorage.removeItem('currentUser');
        localStorage.removeItem('menuInfo');
        this.currentUserSubject.next(null);
        window.location.href = './logout';
    };
    OAuthAuthenticationService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Injector }
    ]; };
    OAuthAuthenticationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function OAuthAuthenticationService_Factory() { return new OAuthAuthenticationService(ɵɵinject(HttpClient), ɵɵinject(INJECTOR)); }, token: OAuthAuthenticationService, providedIn: "root" });
    OAuthAuthenticationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [HttpClient, Injector])
    ], OAuthAuthenticationService);
    return OAuthAuthenticationService;
}(AuthenticationService));

var AuthenticationInterceptor = /** @class */ (function () {
    function AuthenticationInterceptor() {
        this.AUTH_HEADER = 'Authorization';
        this.token = 'secrettoken';
        this.refreshTokenInProgress = false;
        this.refreshTokenSubject = new BehaviorSubject(null);
    }
    AuthenticationInterceptor.prototype.intercept = function (req, next) {
        var _this = this;
        if (!req.headers.has('Content-Type')) {
            req = req.clone({
                headers: req.headers.set('Content-Type', 'application/json')
            });
        }
        req = this.addAuthenticationToken(req);
        return next.handle(req).pipe(catchError(function (err) {
            if (err && err.status === 401) {
                if (_this.refreshTokenInProgress) {
                    return _this.refreshTokenSubject.pipe(filter(function (result) { return result !== null; }), take(1), switchMap(function () { return next.handle(_this.addAuthenticationToken(req)); }));
                }
                else {
                    _this.refreshTokenInProgress = true;
                    _this.refreshTokenSubject.next(null);
                    return _this.refreshAccessToken().pipe(switchMap(function (success) {
                        _this.refreshTokenSubject.next(success);
                        return next.handle(_this.addAuthenticationToken(req));
                    }), finalize(function () { return _this.refreshTokenInProgress = false; }));
                }
            }
            else {
                return throwError(err);
            }
        }));
    };
    AuthenticationInterceptor.prototype.refreshAccessToken = function () {
        return of('secret token');
    };
    AuthenticationInterceptor.prototype.addAuthenticationToken = function (request) {
        // If we do not have a token yet then we should not set the header.
        // Here we could first retrieve the token from where we store it.
        if (!this.token) {
            return request;
        }
        // If you are calling an outside domain then do not add the token.
        if (!request.url.match(/localhost:4200\//)) {
            return request;
        }
        return request.clone({
            headers: request.headers.set(this.AUTH_HEADER, 'Bearer ' + this.token)
        });
    };
    AuthenticationInterceptor = __decorate([
        Injectable()
    ], AuthenticationInterceptor);
    return AuthenticationInterceptor;
}());

var AuthorizationInterceptor = /** @class */ (function () {
    function AuthorizationInterceptor() {
    }
    AuthorizationInterceptor.prototype.intercept = function (req, next) {
        return next.handle(req).pipe(catchError(function (error) {
            return throwError(error);
        }));
    };
    AuthorizationInterceptor = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [])
    ], AuthorizationInterceptor);
    return AuthorizationInterceptor;
}());

var users = [{ username: 'test', password: 'test', firstName: 'Test', lastName: 'User' }];
var AuthenticationFakeBackendInterceptor = /** @class */ (function () {
    function AuthenticationFakeBackendInterceptor() {
    }
    AuthenticationFakeBackendInterceptor.prototype.intercept = function (request, next) {
        var url = request.url, method = request.method, headers = request.headers, body = request.body;
        return of(null)
            .pipe(mergeMap(handleRoute))
            .pipe(materialize())
            .pipe(delay(500))
            .pipe(dematerialize());
        function handleRoute() {
            switch (true) {
                case url.endsWith('/users/authenticate') && method === 'POST':
                    return authenticate();
                case url.endsWith('/users') && method === 'GET':
                    return getUsers();
                default:
                    // pass through any requests not handled above
                    return next.handle(request);
            }
        }
        function authenticate() {
            var username = body.username, password = body.password;
            var user = users.find(function (x) { return x.username === username && x.password === password; });
            if (!user) {
                return error('Username or password is incorrect');
            }
            return ok({
                username: user.username,
                firstName: user.firstName,
                lastName: user.lastName,
                token: 'fake-jwt-token'
            });
        }
        function getUsers() {
            if (!isLoggedIn()) {
                return unauthorized();
            }
            return ok(users);
        }
        // helper functions
        function ok(bodyContent) {
            return of(new HttpResponse({ status: 200, body: bodyContent }));
        }
        function error(message) {
            return throwError({ error: { message: message } });
        }
        function unauthorized() {
            return throwError({ status: 401, error: { message: 'Unauthorised' } });
        }
        function isLoggedIn() {
            return headers.get('Authorization') === 'Bearer fake-jwt-token';
        }
    };
    AuthenticationFakeBackendInterceptor = __decorate([
        Injectable()
    ], AuthenticationFakeBackendInterceptor);
    return AuthenticationFakeBackendInterceptor;
}());

var basePath = './service/authorize';
var data = ['new', 'view', 'delete', 'edit', 'export'];
var AuthorizationFakeBackendInterceptor = /** @class */ (function () {
    function AuthorizationFakeBackendInterceptor() {
    }
    AuthorizationFakeBackendInterceptor.prototype.intercept = function (request, next) {
        var url = request.url, method = request.method, headers = request.headers, body = request.body;
        return of(null)
            .pipe(mergeMap(handleRoute))
            .pipe(materialize())
            .pipe(dematerialize());
        function handleRoute() {
            switch (true) {
                case url.endsWith(basePath) && method === 'POST':
                    return authorize();
                default:
                    // pass through any requests not handled above
                    return next.handle(request);
            }
        }
        function authorize() {
            return ok(data);
        }
        // helper functions
        function ok(bodyContent) {
            return of(new HttpResponse({ status: 200, body: bodyContent }));
        }
        function error(message) {
            return throwError({ error: { message: message } });
        }
    };
    AuthorizationFakeBackendInterceptor = __decorate([
        Injectable()
    ], AuthorizationFakeBackendInterceptor);
    return AuthorizationFakeBackendInterceptor;
}());

var programsData = [
	"CUSTOMER",
	"COUNTRY",
	"SYSTEM_SETTINGS",
	"USER_ROLE",
	"USER",
	"system_settings_information",
	"system_settings_password",
	"system_settings_userpolicy",
	"VALPOS",
	"APPLICATION",
	"HOBBY",
	"TAGS",
	"COMMISSSIONS"
];

var basePath$1 = '/service/security/programs';
var ProgramsFakeBackendInterceptor = /** @class */ (function () {
    function ProgramsFakeBackendInterceptor() {
    }
    ProgramsFakeBackendInterceptor.prototype.intercept = function (request, next) {
        var url = request.url, method = request.method, headers = request.headers, body = request.body;
        var data = programsData;
        return of(null)
            .pipe(mergeMap(handleRoute))
            .pipe(materialize())
            .pipe(delay(50))
            .pipe(dematerialize());
        function handleRoute() {
            switch (true) {
                case url.match('.*' + basePath$1) && method === 'GET':
                    return getList();
                default:
                    // pass through any requests not handled above
                    return next.handle(request);
            }
        }
        function getList() {
            return ok(data);
        }
        // helper functions
        function ok(bodyContent) {
            return of(new HttpResponse({ status: 200, body: bodyContent }));
        }
        function error(message) {
            return throwError({ error: { message: message } });
        }
    };
    ProgramsFakeBackendInterceptor = __decorate([
        Injectable()
    ], ProgramsFakeBackendInterceptor);
    return ProgramsFakeBackendInterceptor;
}());

var controlsData = [
	"new",
	"view",
	"edit",
	"delete",
	"export",
	"audit"
];

var basePath$2 = '/service/security/controls';
var ControlsByProgramsFakeBackendInterceptor = /** @class */ (function () {
    function ControlsByProgramsFakeBackendInterceptor() {
    }
    ControlsByProgramsFakeBackendInterceptor.prototype.intercept = function (request, next) {
        var url = request.url, method = request.method, headers = request.headers, body = request.body;
        var data = controlsData;
        return of(null)
            .pipe(mergeMap(handleRoute))
            .pipe(materialize())
            .pipe(delay(50))
            .pipe(dematerialize());
        function handleRoute() {
            switch (true) {
                case url.indexOf(basePath$2) > -1 && method === 'GET':
                    return getList();
                default:
                    // pass through any requests not handled above
                    return next.handle(request);
            }
        }
        function getList() {
            return ok(data);
        }
        // helper functions
        function ok(bodyContent) {
            return of(new HttpResponse({ status: 200, body: bodyContent }));
        }
        function error(message) {
            return throwError({ error: { message: message } });
        }
    };
    ControlsByProgramsFakeBackendInterceptor = __decorate([
        Injectable()
    ], ControlsByProgramsFakeBackendInterceptor);
    return ControlsByProgramsFakeBackendInterceptor;
}());

/*
 * Public API Surface of xdf-security
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthGuard, AuthenticationFakeBackendInterceptor, AuthenticationInterceptor, AuthorizationFakeBackendInterceptor, AuthorizationInterceptor, AuthorizationResolver, AuthorizationResource, AuthorizationService, ByteAuthenticationService, ControlsByProgramsFakeBackendInterceptor, LoginComponent, OAuthAuthenticationService, OAuthGuard, ProgramsFakeBackendInterceptor, ResourceAuthGuard, XdfSecurityModule };
//# sourceMappingURL=xdf-security.js.map
